@@ -60,7 +60,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         if len(self.displaystring)<12:
             self.displaystring=self.displaystring+'3'
             self.lcd.setText(self.displaystring)
-            
+            print'hello'''
     
     @pyqtSignature("")
     def on_pushButton_4_pressed(self):
@@ -267,7 +267,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Change the Display Colour to Red
         """
-        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_display.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
+        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_displayw.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
 color: rgb(244,36,4);""")
 
         
@@ -276,7 +276,7 @@ color: rgb(244,36,4);""")
         """
         Slot documentation goes here.
         """
-        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_display.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
+        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_displayw.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
 color: rgb(42,211,26);""")
     
     @pyqtSignature("")
@@ -284,7 +284,7 @@ color: rgb(42,211,26);""")
         """
         Slot documentation goes here.
         """
-        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_display.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
+        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_displayw.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
 color: rgb(238, 156, 14);""")
     
     @pyqtSignature("")
@@ -292,8 +292,8 @@ color: rgb(238, 156, 14);""")
         """
         Slot documentation goes here.
         """
-        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_display.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
-color: rgb(255,255,255);""")
+        self.lcd.setStyleSheet("""background-image: url(:/images/calculator_displayw.png); border-width:5px; border-style:solid;                                               border-color:rgb(73, 73, 73);; 
+color: rgb(38,52,255);""")
 
 
 
